aboutsummaryrefslogtreecommitdiff
path: root/src/ext/mod.rs
diff options
context:
space:
mode:
authorAustin Hellyer <[email protected]>2016-11-22 07:57:51 -0800
committerAustin Hellyer <[email protected]>2016-11-22 07:57:51 -0800
commitd4726f899cf6b86d805a8a2a77ec57782ec3bdd6 (patch)
tree7966be3c6d6c4284bb618b88b3f146dd412af677 /src/ext/mod.rs
parentDon't typo CreateEmbed::image field (diff)
downloadserenity-d4726f899cf6b86d805a8a2a77ec57782ec3bdd6.tar.xz
serenity-d4726f899cf6b86d805a8a2a77ec57782ec3bdd6.zip
Rename the State to Cache
Diffstat (limited to 'src/ext/mod.rs')
-rw-r--r--src/ext/mod.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/ext/mod.rs b/src/ext/mod.rs
index 312074b..4484b0b 100644
--- a/src/ext/mod.rs
+++ b/src/ext/mod.rs
@@ -6,16 +6,16 @@
//! See each extension's module-level documentation for more information.
//!
//! Note that the framework module requires the `framework` feature to be
//! enabled (enabled by default), the state requires the `state` feature to be
//! enabled (enabled by default), and voice support requires the `voice` feature
//! to be enabled (disabled by default).
//!
//! [`Client`]: ../client/struct.Client.html
//! [`Connection`]: ../client/struct.Connection.html
+#[cfg(feature = "cache")]
+pub mod cache;
#[cfg(feature = "framework")]
pub mod framework;
-#[cfg(feature = "state")]
-pub mod state;
#[cfg(feature = "voice")]
pub mod voice;
@@ -6,16 +6,16 @@
//!
//! Note that the framework module requires the `framework` feature to be
-//! enabled (enabled by default), the state requires the `state` feature to be
+//! enabled (enabled by default), the cache requires the `cache` feature to be
//! enabled (enabled by default), and voice support requires the `voice` feature
//! to be enabled (disabled by default).